### 高度な設定

このセクションは、このソフトウェアの上級ユーザー向けです。ここでは以下の情報を見つけることができます：

1. [**高度な設定**](./advanced.md)
<br>
このセクションでは、特定のソース/ターゲット言語の指定、翻訳サービスの切り替えなどが可能です。

2. [**言語コード**](./言語コード.md)
<br>
翻訳元/翻訳先の言語にどのコードを使用すべきかわからない場合は、こちらで確認できます。

3. [**翻訳サービスドキュメント**](./Documentation-of-Translation-Services.md)
<br>
使用中の翻訳サービスが提供するドキュメントを確認する必要がある場合は、このページを参照してください。

<div align="right"> 
<h6><small>このページの一部のコンテンツはGPTによって翻訳されており、エラーが含まれている可能性があります。</small></h6>